@@ -57,7 +57,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'CFontz\'',
+          '$selected.is_set(\'CFontz\')',
           {
             'level' => 'normal'
           }
@@ -72,7 +72,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'CFontzPacket\'',
+          '$selected.is_set(\'CFontzPacket\')',
           {
             'level' => 'normal'
           }
@@ -87,7 +87,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'CwLnx\'',
+          '$selected.is_set(\'CwLnx\')',
           {
             'level' => 'normal'
           }
@@ -102,7 +102,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'EyeboxOne\'',
+          '$selected.is_set(\'EyeboxOne\')',
           {
             'level' => 'normal'
           }
@@ -117,7 +117,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'IOWarrior\'',
+          '$selected.is_set(\'IOWarrior\')',
           {
             'level' => 'normal'
           }
@@ -132,7 +132,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'IrMan\'',
+          '$selected.is_set(\'IrMan\')',
           {
             'level' => 'normal'
           }
@@ -147,7 +147,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'MD8800\'',
+          '$selected.is_set(\'MD8800\')',
           {
             'level' => 'normal'
           }
@@ -162,7 +162,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'MtxOrb\'',
+          '$selected.is_set(\'MtxOrb\')',
           {
             'level' => 'normal'
           }
@@ -177,7 +177,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'NoritakeVFD\'',
+          '$selected.is_set(\'NoritakeVFD\')',
           {
             'level' => 'normal'
           }
@@ -192,7 +192,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'SureElec\'',
+          '$selected.is_set(\'SureElec\')',
           {
             'level' => 'normal'
           }
@@ -207,7 +207,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'bayrad\'',
+          '$selected.is_set(\'bayrad\')',
           {
             'level' => 'normal'
           }
@@ -222,7 +222,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'curses\'',
+          '$selected.is_set(\'curses\')',
           {
             'level' => 'normal'
           }
@@ -237,7 +237,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'ea65\'',
+          '$selected.is_set(\'ea65\')',
           {
             'level' => 'normal'
           }
@@ -252,7 +252,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'g15\'',
+          '$selected.is_set(\'g15\')',
           {
             'level' => 'normal'
           }
@@ -267,7 +267,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'glcd\'',
+          '$selected.is_set(\'glcd\')',
           {
             'level' => 'normal'
           }
@@ -282,7 +282,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'glcdlib\'',
+          '$selected.is_set(\'glcdlib\')',
           {
             'level' => 'normal'
           }
@@ -297,7 +297,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'glk\'',
+          '$selected.is_set(\'glk\')',
           {
             'level' => 'normal'
           }
@@ -312,7 +312,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'hd44780\'',
+          '$selected.is_set(\'hd44780\')',
           {
             'level' => 'normal'
           }
@@ -327,7 +327,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'icp_a106\'',
+          '$selected.is_set(\'icp_a106\')',
           {
             'level' => 'normal'
           }
@@ -342,7 +342,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'imon\'',
+          '$selected.is_set(\'imon\')',
           {
             'level' => 'normal'
           }
@@ -357,7 +357,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'imonlcd\'',
+          '$selected.is_set(\'imonlcd\')',
           {
             'level' => 'normal'
           }
@@ -372,7 +372,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'irtrans\'',
+          '$selected.is_set(\'irtrans\')',
           {
             'level' => 'normal'
           }
@@ -387,7 +387,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'joy\'',
+          '$selected.is_set(\'joy\')',
           {
             'level' => 'normal'
           }
@@ -402,7 +402,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'lb216\'',
+          '$selected.is_set(\'lb216\')',
           {
             'level' => 'normal'
           }
@@ -417,7 +417,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'lcdm001\'',
+          '$selected.is_set(\'lcdm001\')',
           {
             'level' => 'normal'
           }
@@ -432,7 +432,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'lcterm\'',
+          '$selected.is_set(\'lcterm\')',
           {
             'level' => 'normal'
           }
@@ -447,7 +447,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'lirc\'',
+          '$selected.is_set(\'lirc\')',
           {
             'level' => 'normal'
           }
@@ -462,7 +462,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'lis\'',
+          '$selected.is_set(\'lis\')',
           {
             'level' => 'normal'
           }
@@ -477,7 +477,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'mdm166a\'',
+          '$selected.is_set(\'mdm166a\')',
           {
             'level' => 'normal'
           }
@@ -497,7 +497,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'ms6931\'',
+          '$selected.is_set(\'ms6931\')',
           {
             'level' => 'normal'
           }
@@ -512,7 +512,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'mtc_s16209x\'',
+          '$selected.is_set(\'mtc_s16209x\')',
           {
             'level' => 'normal'
           }
@@ -527,7 +527,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'mx5000\'',
+          '$selected.is_set(\'mx5000\')',
           {
             'level' => 'normal'
           }
@@ -542,7 +542,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'picolcd\'',
+          '$selected.is_set(\'picolcd\')',
           {
             'level' => 'normal'
           }
@@ -557,7 +557,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'pyramid\'',
+          '$selected.is_set(\'pyramid\')',
           {
             'level' => 'normal'
           }
@@ -572,7 +572,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'rawserial\'',
+          '$selected.is_set(\'rawserial\')',
           {
             'level' => 'normal'
           }
@@ -587,7 +587,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'sdeclcd\'',
+          '$selected.is_set(\'sdeclcd\')',
           {
             'level' => 'normal'
           }
@@ -602,7 +602,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'sed1330\'',
+          '$selected.is_set(\'sed1330\')',
           {
             'level' => 'normal'
           }
@@ -617,7 +617,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'sed1520\'',
+          '$selected.is_set(\'sed1520\')',
           {
             'level' => 'normal'
           }
@@ -632,7 +632,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'serialPOS\'',
+          '$selected.is_set(\'serialPOS\')',
           {
             'level' => 'normal'
           }
@@ -647,7 +647,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'serialVFD\'',
+          '$selected.is_set(\'serialVFD\')',
           {
             'level' => 'normal'
           }
@@ -662,7 +662,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'shuttleVFD\'',
+          '$selected.is_set(\'shuttleVFD\')',
           {
             'level' => 'normal'
           }
@@ -677,7 +677,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'sli\'',
+          '$selected.is_set(\'sli\')',
           {
             'level' => 'normal'
           }
@@ -692,7 +692,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'stv5730\'',
+          '$selected.is_set(\'stv5730\')',
           {
             'level' => 'normal'
           }
@@ -707,7 +707,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'svga\'',
+          '$selected.is_set(\'svga\')',
           {
             'level' => 'normal'
           }
@@ -722,7 +722,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'t6963\'',
+          '$selected.is_set(\'t6963\')',
           {
             'level' => 'normal'
           }
@@ -737,7 +737,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'text\'',
+          '$selected.is_set(\'text\')',
           {
             'level' => 'normal'
           }
@@ -752,7 +752,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'tyan\'',
+          '$selected.is_set(\'tyan\')',
           {
             'level' => 'normal'
           }
@@ -767,7 +767,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'ula200\'',
+          '$selected.is_set(\'ula200\')',
           {
             'level' => 'normal'
           }
@@ -782,7 +782,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'vlsys_m428\'',
+          '$selected.is_set(\'vlsys_m428\')',
           {
             'level' => 'normal'
           }
@@ -797,7 +797,7 @@ This model does not support to load several drivers. Loading several drivers is
         },
         'level' => 'hidden',
         'rules' => [
-          '$selected eq \'xosd\'',
+          '$selected.is_set(\'xosd\')',
           {
             'level' => 'normal'
           }
